@@ -233,18 +233,18 @@ static void chkIntFn(void *dummy) { R_CheckUserInterrupt(); }
 int checkInterrupt()
 {
   Rboolean R_ToplevelExec(void (*fun)(void *), void *data);
-  int pressed;
 
-  pressed = (R_ToplevelExec(chkIntFn, NULL) == FALSE);
-  if (pressed)
+  if (CtrlCPressed) return CtrlCPressed;
+
+#if (defined(OPENMP))
+  if (omp_get_thread_num() == 0)
+#endif
     {
-      REprintf("\n\nCtrl-C detected. Stopping computation\n\n");
-      CtrlCPressed = TRUE;
-      R_FlushConsole();
-      R_ProcessEvents();
+      CtrlCPressed = (R_ToplevelExec(chkIntFn, NULL) == FALSE);
+      if (CtrlCPressed) REprintf("\n\nUser interrupt detected. Stopping computation\n\n");
     }
 
-  return (pressed || CtrlCPressed);
+  return (CtrlCPressed);
 }
 
 #endif
